/**
 * Vraća CssRule objekt za dati selektor.
 *
 * @param selector
 */
function getRulesBySelector(selector)
{
    let sheets = document.styleSheets,
        regex = new RegExp(selector.replace(/([.\]\[])/, '\\$1') + '\s*[,{]', 'g'),
        rules = [];

    for (let i = 0; i < sheets.length; i++) {
        let classes = sheets[i].rules || sheets[i].cssRules;
        if (!classes) continue;

        for (let j = 0; j < classes.length; j++) {
            if (regex.test(classes[j].selectorText)) {
                rules.push(classes[j]);
            }
        }
    }

    return rules;
}

/**
 * Dodaje selektore svim klasama koje sadrže target selektor.
 *
 * @param target
 * @param added
 */
function expandSelector(target, added)
{
    getRulesBySelector(target).forEach(function(rule) {
        rule.selectorText += ',' + added;
    });
}

/**
 * Vraća vrijednost CSS varijable.
 *
 * @param name
 * @param element
 * @returns {string}
 */
function getVariable(name, element)
{
    element = element || document.documentElement;

    return element.style.getPropertyValue(name);
}

/**
 * Postavlja vrijednost CSS varijable.
 *
 * @param name
 * @param value
 * @param element
 */
function setVariable(name, value, element)
{
    element = element || document.documentElement;

    element.style.setProperty(name, value);
}

module.exports = {
    expandSelector,
    getVariable,
    setVariable
};