<?php
use Psr\Cache\CacheItemPoolInterface;
use Symfony\Component\Cache\Adapter\FilesystemAdapter;

/**
 * Vraća keš za namespace.
 *
 * @param string $namespace
 * @param int    $ttl
 *
 * @return CacheItemPoolInterface
 */
function ep_cache($namespace = '', $ttl = 0)
{
	static $caches, $cacheDir;

	if (!isset($caches)) {
		$caches = [];
	}

	if (!array_key_exists($namespace, $caches)) {
		if (!isset($cacheDir)) {
			$uploadDir = wp_get_upload_dir();
			$cacheDir = $uploadDir['basedir'] . '/cache/ep';
		}

		if (WP_DEBUG) {
			$caches[$namespace] = new \Symfony\Component\Cache\Adapter\NullAdapter();
		} else {
			$caches[$namespace] = new FilesystemAdapter($namespace, $ttl, $cacheDir);
		}
	}

	return $caches[$namespace];
}

/**
 * Vraća instancu Twig-a.
 *
 * @return Twig_Environment
 */
function ep_twig()
{
	static $twig;

	if (!isset($twig)) {
		$paths = apply_filters('ep/twig/paths', []);

		$loader = new Twig_Loader_Filesystem($paths);

		$uploads = wp_get_upload_dir();
		$cacheDir = $uploads['basedir'] . '/cache/ep/twig';

		$twig = new Twig_Environment($loader, [
			'cache' => $cacheDir,
			'debug' => WP_DEBUG,
		]);

		if (WP_DEBUG) {
			$twig->addExtension(new Twig_Extension_Debug());
		}
	}

	return $twig;
}