<?php
namespace EpOld\Component;

use EpOld\Customize\HtmlControl;
use WP_Customize_Manager;

/**
 * Spinner komponenta
 *
 * @package Ep\Component
 */
class Spinner
{
	/**
	 * Kačimo se na WordPress.
	 */
	public function init()
	{
		add_action('customize_register', [$this, 'customize_register']);
		add_action('customize_controls_print_styles', [$this, 'wp_head'], 1);

		add_action('wp_head', [$this, 'wp_head'], 1);
	}

	/**
	 * Registrira postavke u customizer.
	 *
	 * @param WP_Customize_Manager $customizer
	 */
	public function customize_register(WP_Customize_Manager $customizer)
	{
		$customizer->add_setting('spinner_size', [
			'default' => '30px',
			'transport' => 'postMessage',
		]);

		$customizer->add_setting('spinner_border_width', [
			'default' => '2px',
			'transport' => 'postMessage',
		]);

		$customizer->add_setting('spinner_border_color', [
			'default' => '#f3f3f3',
			'transport' => 'postMessage',
		]);

		$customizer->add_setting('spinner_color', [
			'default' => '#153ca5',
			'transport' => 'postMessage',
		]);

		$customizer->add_setting('spinner_speed', [
			'default' => '.5s',
			'transport' => 'postMessage',
		]);

		$customizer->add_section('ep_spinner', [
			'title' => 'EP Spinner',
			'priority' => 30,
		]);

		$customizer->add_control('spinner_size', [
			'label' => 'Veličina spinnera',
			'section' => 'ep_spinner',
			'settings' => 'spinner_size',
		]);

		$customizer->add_control('spinner_border_width', [
			'label' => 'Debljina bordera',
			'section' => 'ep_spinner',
			'settings' => 'spinner_border_width',
		]);

		$customizer->add_control(new \WP_Customize_Color_Control($customizer, 'spinner_border_color', [
			'label' => 'Boja bordera',
			'section' => 'ep_spinner',
			'settings' => 'spinner_border_color',
		]));

		$customizer->add_control(new \WP_Customize_Color_Control($customizer, 'spinner_color', [
			'label' => 'Boja spinnera',
			'section' => 'ep_spinner',
			'settings' => 'spinner_color',
		]));

		$customizer->add_control('spinner_speed', [
			'label' => 'Brzina spinnera',
			'section' => 'ep_spinner',
			'settings' => 'spinner_speed',
		]);

		$customizer->add_control(new HtmlControl($customizer, 'spinner_preview', [
			'label' => 'Pretpregled',
			'section' => 'ep_spinner',
			'html' => '<div class="ep-spinner"></div>',
			'settings' => 'spinner_speed',
		]));
	}

	/**
	 * Dodaje css varijable u dokument.
	 */
	public function wp_head()
	{
		$settings = [
			'spinner_size',
			'spinner_border_width',
			'spinner_border_color',
			'spinner_color',
			'spinner_speed',
		];

		$vars = array_map(function($name) {
			return sprintf('--%s:%s', str_replace('_', '-', $name), get_theme_mod($name));
		}, $settings);

		printf('<style>:root{%s}</style>', implode(';', $vars));
	}
}